check_visibility_gpu_culling

Function check_visibility_gpu_culling 

pub fn check_visibility_gpu_culling(
    query: Query<'_, '_, (&mut ViewVisibility, &InheritedVisibility), (With<NoCpuCulling>, Or<(Changed<InheritedVisibility>, Added<NoCpuCulling>)>)>,
)
Updates the visibility of entities marked with NoCpuCulling.

In this case, the ViewVisibility of each such mesh simply becomes equal to its InheritedVisibility, as the CPU has been instructed to perform no other checks. For performance, we avoid examining any entity that hasn’t changed its inherited visibility.